@@ -5,12 +5,11 @@ sectionview.list <- function(model,
         col_surf = "blue",
         bg_blend = 5,
         mfrow = NULL,
-        Xname = NULL,
-        yname = NULL,
-        Xscale = 1,
-        yscale = 1,
-        ylim = NULL,
+        Xname = NULL, yname = NULL,
+        Xscale = 1, yscale = 1,
+        xlim = NULL, ylim = NULL,
         title = NULL,
+        add = FALSE,
         ...) {
     
     D <- length(model$data$X)
@@ -25,8 +24,11 @@ sectionview.list <- function(model,
         mfrow <- c(nc,nl)
     }
     
-    if (mfrow[1] != 1 || mfrow[2] != 1)
-        par(mfrow=mfrow)
+    if (!isTRUE(add)) {
+        close.screen( all.screens = TRUE )
+        split.screen(figs = mfrow)
+        .split.screen.lim <<- matrix(NaN,ncol=4,nrow=D) # xmin,xmax,ymin,ymax matrix of limits, each row for one dim combination
+    }
     
     # apply scaling factor
     X_doe <- Xscale * model$data$X
@@ -35,6 +37,7 @@ sectionview.list <- function(model,
     
     ## find limits: 'rx' is matrix with min in row 1 and max in row 2
     rx <- apply(X_doe, 2, range)
+    if(!is.null(xlim)) rx <- matrix(xlim,nrow=2,ncol=D)
     rownames(rx) <- c("min", "max") 
     drx <- rx["max", ] - rx["min", ]
     
@@ -54,17 +57,20 @@ sectionview.list <- function(model,
     fcenter <- tryFormat(x = center, drx = drx)
     
     for (d in 1:D) {
+        screen(d)
         
         xdmin <- rx["min", d]
         xdmax <- rx["max", d]
+        xlim = c(xdmin,xdmax)
+        
         xd <- seq(from = xdmin, to = xdmax, length.out = npoints)
         x <- data.frame(t(matrix(as.numeric(center), nrow = D , ncol = npoints)))
-        names(x) <- names(center)
+        if (!is.null(center)) if(!is.null(names(center))) names(x) <- names(center)
         x[ , d] <- xd
         y_mean <- array(0,npoints)
         
         for (i in 1:npoints) {
-            y <- modelPredict(model, newdata = as.array(x[i,]))
+            y <- modelPredict(model, newdata = (x[i,]))
             y_mean[i] <- yscale * y
         }
         
@@ -78,12 +84,27 @@ sectionview.list <- function(model,
             title_d <- title
         }
         
-        plot(xd, y_mean,
+        if (isTRUE(add)) {
+            # re-use global settings for limits of this screen
+            xlim <- c(.split.screen.lim[d,1],.split.screen.lim[d,2])
+            ylim <- c(.split.screen.lim[d,3],.split.screen.lim[d,4])
+            plot(xd, y_mean,
+                    xlab = "", ylab = "",
+                    xlim = xlim, ylim = ylim, 
+                    type = "l",
+                    col = col_surf,
+                    add = TRUE,
+                    ...)
+        } else {
+            .split.screen.lim[d,] <<- matrix(c(xlim[1],xlim[2],ylim[1],ylim[2]),nrow=1)
+            plot(xd, y_mean,
                 xlab = Xname[d], ylab = yname,
                 ylim = ylim, main = title_d,
                 type = "l",
                 col = col_surf,
                 ...)
+            if(D>1) abline(v=center[d],col='black',lty=2)
+        }
         
         n <- dim(X_doe)[1]
         
