@@ -6,7 +6,10 @@ sectionview3d.list <- function(model, center = NULL,
         bg_blend = 5,
         Xname = NULL, yname = NULL,
         Xscale = 1, yscale = 1,
-        ylim = NULL, title = NULL, ...) {
+        xlim = NULL, ylim = NULL, 
+        title = NULL, 
+        add = FALSE,
+        ...) {
     
     require(rgl)
     
@@ -35,6 +38,7 @@ sectionview3d.list <- function(model, center = NULL,
     
     ## find limits: 'rx' is matrix with min in row 1 and max in row 2
     rx <- apply(X_doe, 2, range)
+    if(!is.null(xlim)) rx <- matrix(xlim,nrow=2,ncol=D)
     rownames(rx) <- c("min", "max") 
     drx <- rx["max", ] - rx["min", ]
     
@@ -75,7 +79,7 @@ sectionview3d.list <- function(model, center = NULL,
         xd2 <- seq(from = xdmin[2], to = xdmax[2], length.out = npoints[2])
         
         x <- data.frame(t(matrix(as.numeric(center), nrow = D, ncol = npoints_all)))
-        names(x) <- names(center)
+        if (!is.null(center)) if(!is.null(names(center))) names(x) <- names(center)
         x[ , d] <- expand.grid(xd1, xd2)
         
         y_mean <- array(0, npoints_all)
@@ -100,14 +104,16 @@ sectionview3d.list <- function(model, center = NULL,
             title_d <-  title
         }
         
-        open3d()
-        
-        plot3d(x = x[,1], y = x[,2], z = y_mean,
+        if (!isTRUE(add)) {
+            open3d()
+         
+            plot3d(x = x[,1], y = x[,2], z = y_mean,
                 xlab = Xname[d[1]], ylab = Xname[d[2]], zlab = yname,
                 xlim = xlim, ylim = ylim, zlim = zlim,
                 type = "n", main = title_d,
                 col = col_surf,
                 ...)
+        }
         
         surface3d(x = xd1, y = xd2, z = yd_mean,
                 col = col_surf, alpha = 0.5, box = FALSE)
