@@ -40,6 +40,7 @@ setMethod("sectionview", "km",
                 yname = NULL,
                 Xscale = 1,
                 yscale = 1,
+                xlim = NULL,
                 ylim = NULL,
                 title = NULL,
                 ...){
@@ -58,6 +59,7 @@ setMethod("sectionview", "km",
                     yname=yname,
                     Xscale = Xscale,
                     yscale = yscale,
+                    xlim = xlim,
                     ylim = ylim,
                     title = title,
                     ...)		
@@ -76,6 +78,7 @@ setMethod("sectionview", "list",
                 yname = NULL,
                 Xscale = 1,
                 yscale = 1,
+                xlim = NULL,
                 ylim = NULL,
                 title = NULL,
                 ...){
@@ -91,12 +94,45 @@ setMethod("sectionview", "list",
                     yname = yname,
                     Xscale = Xscale,
                     yscale = yscale,
+                    xlim = xlim,
                     ylim = ylim,
                     title = title,
                     ...)		
         }
 )
 
+setMethod("sectionview", "function", 
+        function(model,dim,
+                center = NULL,
+                npoints = 100,
+                col = "blue",
+                mfrow = NULL,
+                Xname = NULL,
+                yname = NULL,
+                Xscale = 1,
+                yscale = 1,
+                xlim = c(0,1),
+                ylim = NULL,
+                title = NULL,
+                ...){
+            
+            sectionview.fun(fun = model,
+                    dim = dim,
+                    center = center,
+                    npoints = npoints,
+                    col = col,
+                    mfrow = mfrow,
+                    Xname = Xname,
+                    yname = yname,
+                    Xscale = Xscale,
+                    yscale = yscale,
+                    xlim = xlim,
+                    ylim = ylim,
+                    title = title,
+                    ...)        
+        }
+)
+
 #Wrapper for sectionview3d
 if(!isGeneric("sectionview3d")) {
     setGeneric(name = "sectionview3d",
@@ -119,6 +155,7 @@ setMethod("sectionview3d", "km",
                 yname = NULL,
                 Xscale = 1,
                 yscale = 1,
+                xlim = NULL,
                 ylim = NULL,
                 title = NULL,
                 ...){
@@ -137,6 +174,7 @@ setMethod("sectionview3d", "km",
                     yname = yname,
                     Xscale = Xscale,
                     yscale = yscale,
+                    xlim = xlim,
                     ylim = ylim,
                     title = title,
                     ...)		
@@ -155,6 +193,7 @@ setMethod("sectionview3d", "list",
                 yname = NULL,
                 Xscale = 1,
                 yscale = 1,
+                xlim = NULL,
                 ylim = NULL,
                 title = NULL,
                 ...){
@@ -170,13 +209,45 @@ setMethod("sectionview3d", "list",
                     yname = yname,
                     Xscale = Xscale,
                     yscale = yscale,
-                    ylim =
-                            ylim,
+                    xlim = xlim,
+                    ylim = ylim,
                     title = title,
                     ...)		
         }
 )
 
+setMethod("sectionview3d", "function", 
+        function(model,dim,
+                center = NULL,
+                axis = NULL,
+                npoints = 20,
+                col = "blue",
+                Xname = NULL,
+                yname = NULL,
+                Xscale = 1,
+                yscale = 1,
+                xlim = c(0,1),
+                ylim = NULL,
+                title = NULL,
+                ...){
+            
+            sectionview3d.fun(fun = model,
+                    dim = dim,
+                    center = center,
+                    axis = axis,
+                    npoints = npoints,
+                    col = col,
+                    Xname = Xname,
+                    yname = yname,
+                    Xscale = Xscale,
+                    yscale = yscale,
+                    xlim = xlim,
+                    ylim = ylim,
+                    title = title,
+                    ...)        
+        }
+)
+
 #Wrapper for contourview
 if(!isGeneric("contourview")) {
     setGeneric(name = "contourview",
@@ -197,6 +268,7 @@ setMethod("contourview", "km",
                 yname = NULL,
                 Xscale = 1,
                 yscale = 1,
+                xlim = NULL,
                 ylim = NULL,
                 title = NULL,
                 ...){
@@ -213,6 +285,7 @@ setMethod("contourview", "km",
                     yname = yname,
                     Xscale = Xscale,
                     yscale = yscale,
+                    xlim = xlim,
                     ylim = ylim,
                     title = title,
                     ...)        
@@ -231,6 +304,7 @@ setMethod("contourview", "list",
                 yname = NULL,
                 Xscale = 1,
                 yscale = 1,
+                xlim = NULL,
                 ylim = NULL,
                 title = NULL,
                 ...){
@@ -246,8 +320,40 @@ setMethod("contourview", "list",
                     yname = yname,
                     Xscale = Xscale,
                     yscale = yscale,
-                    ylim =
-                            ylim,
+                    xlim = xlim,
+                    ylim = ylim,
+                    title = title,
+                    ...)        
+        }
+)
+
+setMethod("contourview", "function", 
+        function(model,dim,
+                center = NULL,
+                npoints = 20,
+                col = "blue",
+                nlevels = 10,
+                Xname = NULL,
+                yname = NULL,
+                Xscale = 1,
+                yscale = 1,
+                xlim = c(0,1),
+                ylim = NULL,
+                title = NULL,
+                ...){
+            
+            contourview.fun(fun = model,
+                    dim = dim,
+                    center = center,
+                    npoints = npoints,
+                    col = col,
+                    nlevels = nlevels,
+                    Xname = Xname,
+                    yname = yname,
+                    Xscale = Xscale,
+                    yscale = yscale,
+                    xlim = xlim,
+                    ylim = ylim,
                     title = title,
                     ...)        
         }
